@@ -47,7 +47,6 @@ public:
         m_yearFilter = -1;
         m_monthFilter = -1;
         m_dayFilter = -1;
-        m_sortingOption = SortAuto;
     }
     Term m_term;
 
@@ -60,8 +59,6 @@ public:
     int m_monthFilter;
     int m_dayFilter;
 
-    SortingOption m_sortingOption;
-    QString m_sortingProperty;
     QVariantMap m_customOptions;
 };
 
@@ -98,7 +95,7 @@ Term Query::term() const
 
 void Query::addType(const QString& type)
 {
-    d->m_types << type.split(QLatin1Char('/'), QString::SkipEmptyParts);
+    d->m_types << type.split('/', QString::SkipEmptyParts);
 }
 
 void Query::addTypes(const QStringList& typeList)
@@ -176,27 +173,6 @@ int Query::dayFilter() const
     return d->m_dayFilter;
 }
 
-void Query::setSortingOption(Query::SortingOption option)
-{
-    d->m_sortingOption = option;
-}
-
-Query::SortingOption Query::sortingOption() const
-{
-    return d->m_sortingOption;
-}
-
-void Query::setSortingProperty(const QString& property)
-{
-    d->m_sortingOption = SortProperty;
-    d->m_sortingProperty = property;
-}
-
-QString Query::sortingProperty() const
-{
-    return d->m_sortingProperty;
-}
-
 void Query::addCustomOption(const QString& option, const QVariant& value)
 {
     d->m_customOptions.insert(option, value);
@@ -254,34 +230,29 @@ QByteArray Query::toJSON()
     QVariantMap map;
 
     if (!d->m_types.isEmpty())
-        map[QLatin1String("type")] = d->m_types;
+        map["type"] = d->m_types;
 
     if (d->m_limit != defaultLimit)
-        map[QLatin1String("limit")] = d->m_limit;
+        map["limit"] = d->m_limit;
 
     if (d->m_offset)
-        map[QLatin1String("offset")] = d->m_offset;
+        map["offset"] = d->m_offset;
 
     if (!d->m_searchString.isEmpty())
-        map[QLatin1String("searchString")] = d->m_searchString;
+        map["searchString"] = d->m_searchString;
 
     if (d->m_term.isValid())
-        map[QLatin1String("term")] = QVariant(d->m_term.toVariantMap());
+        map["term"] = QVariant(d->m_term.toVariantMap());
 
     if (d->m_yearFilter >= 0)
-        map[QLatin1String("yearFilter")] = d->m_yearFilter;
+        map["yearFilter"] = d->m_yearFilter;
     if (d->m_monthFilter >= 0)
-        map[QLatin1String("monthFilter")] = d->m_monthFilter;
+        map["monthFilter"] = d->m_monthFilter;
     if (d->m_dayFilter >= 0)
-        map[QLatin1String("dayFilter")] = d->m_dayFilter;
-
-    if (d->m_sortingOption != SortAuto)
-        map[QLatin1String("sortingOption")] = static_cast<int>(d->m_sortingOption);
-    if (!d->m_sortingProperty.isEmpty())
-        map[QLatin1String("sortingProperty")] = d->m_sortingProperty;
+        map["dayFilter"] = d->m_dayFilter;
 
     if (d->m_customOptions.size())
-        map[QLatin1String("customOptions")] = d->m_customOptions;
+        map["customOptions"] = d->m_customOptions;
 
     QJsonObject jo = QJsonObject::fromVariantMap(map);
     QJsonDocument jdoc;
@@ -296,37 +267,28 @@ Query Query::fromJSON(const QByteArray& arr)
     const QVariantMap map = jdoc.object().toVariantMap();
 
     Query query;
-    query.d->m_types = map[QLatin1String("type")].toStringList();
+    query.d->m_types = map["type"].toStringList();
 
-    if (map.contains(QLatin1String("limit")))
-        query.d->m_limit = map[QLatin1String("limit")].toUInt();
+    if (map.contains("limit"))
+        query.d->m_limit = map["limit"].toUInt();
     else
         query.d->m_limit = defaultLimit;
 
-    query.d->m_offset = map[QLatin1String("offset")].toUInt();
-    query.d->m_searchString = map[QLatin1String("searchString")].toString();
-    query.d->m_term = Term::fromVariantMap(map[QLatin1String("term")].toMap());
+    query.d->m_offset = map["offset"].toUInt();
+    query.d->m_searchString = map["searchString"].toString();
+    query.d->m_term = Term::fromVariantMap(map["term"].toMap());
 
-    if (map.contains(QLatin1String("yearFilter")))
-        query.d->m_yearFilter = map[QLatin1String("yearFilter")].toInt();
-    if (map.contains(QLatin1String("monthFilter")))
-        query.d->m_monthFilter = map[QLatin1String("monthFilter")].toInt();
-    if (map.contains(QLatin1String("dayFilter")))
-        query.d->m_dayFilter = map[QLatin1String("dayFilter")].toInt();
+    if (map.contains("yearFilter"))
+        query.d->m_yearFilter = map["yearFilter"].toInt();
+    if (map.contains("monthFilter"))
+        query.d->m_monthFilter = map["monthFilter"].toInt();
+    if (map.contains("dayFilter"))
+        query.d->m_dayFilter = map["dayFilter"].toInt();
 
-    if (map.contains(QLatin1String("sortingOption"))) {
-        int option = map.value("sortingOption").toInt();
-        query.d->m_sortingOption = static_cast<SortingOption>(option);
-    }
-
-    if (map.contains(QLatin1String("sortingProperty"))) {
-        query.d->m_sortingProperty = map.value("sortingProperty").toString();
-    }
-
-    if (map.contains(QLatin1String("customOptions"))) {
-        QVariant var = map[QLatin1String("customOptions")];
+    if (map.contains("customOptions")) {
+        QVariant var = map["customOptions"];
         if (var.type() == QVariant::Map) {
-            query.d->m_customOptions = map[QLatin1String("customOptions")].toMap();
+            query.d->m_customOptions = map["customOptions"].toMap();
         }
         else if (var.type() == QVariant::Hash) {
             QVariantHash hash = var.toHash();
@@ -361,14 +323,14 @@ Query Query::fromSearchUrl(const QUrl& url)
         return Query();
 
     QUrlQuery urlQuery(url);
-    QString jsonString = urlQuery.queryItemValue(QLatin1String("json"), QUrl::FullyDecoded);
+    QString jsonString = urlQuery.queryItemValue(QLatin1String("json"));
     return Query::fromJSON(jsonString.toUtf8());
 }
 
 QString Query::titleFromQueryUrl(const QUrl& url)
 {
     QUrlQuery urlQuery(url);
-    return urlQuery.queryItemValue(QLatin1String("title"), QUrl::FullyDecoded);
+    return urlQuery.queryItemValue("title");
 }
 
 bool Query::operator==(const Query& rhs) const
@@ -376,8 +338,7 @@ bool Query::operator==(const Query& rhs) const
     if (rhs.d->m_limit != d->m_limit || rhs.d->m_offset != d->m_offset ||
         rhs.d->m_dayFilter != d->m_dayFilter || rhs.d->m_monthFilter != d->m_monthFilter ||
         rhs.d->m_yearFilter != d->m_yearFilter || rhs.d->m_customOptions != d->m_customOptions ||
-        rhs.d->m_searchString != d->m_searchString || rhs.d->m_sortingProperty != d->m_sortingProperty ||
-        rhs.d->m_sortingOption != d->m_sortingOption)
+        rhs.d->m_searchString != d->m_searchString )
     {
         return false;
     }
