@@ -27,21 +27,22 @@
 
 using namespace Baloo;
 
-class Baloo::ResultIteratorPrivate : public QSharedData {
-public:
-    ResultIteratorPrivate()
-        : queryId(0)
-        , store(0) {
-    }
+ResultIteratorPrivate::ResultIteratorPrivate()
+    : queryId(0)
+    , store(0)
+{
+}
 
-    ~ResultIteratorPrivate() {
-        if (store)
-            store->close(queryId);
+/*
+ * FIXME: The linker complains if it is not present in the header.
+ResultIteratorPrivate::~ResultIteratorPrivate()
+{
+    if (store) {
+        store->close(queryId);
     }
+}
+*/
 
-    int queryId;
-    SearchStore* store;
-};
 
 ResultIterator::ResultIterator(int id, SearchStore* store)
     : d(new ResultIteratorPrivate)
@@ -55,15 +56,6 @@ ResultIterator::ResultIterator()
 {
 }
 
-ResultIterator::ResultIterator(const ResultIterator& rhs)
-    : d(rhs.d)
-{
-}
-
-ResultIterator::~ResultIterator()
-{
-}
-
 bool ResultIterator::next()
 {
     if (d->store)
