@@ -22,13 +22,13 @@
 
 #include "query.h"
 
-#include <QApplication>
+#include <QCoreApplication>
 #include <QTimer>
-#include <KDebug>
+#include <QDebug>
 
 #include <iostream>
 
-class App : public QApplication {
+class App : public QCoreApplication {
     Q_OBJECT
 public:
     App(int& argc, char** argv, int flags = ApplicationFlags);
@@ -44,15 +44,15 @@ int main(int argc, char** argv)
     App app(argc, argv);
 
     if (argc != 2) {
-        kError() << "Proper args required";
+        qWarning() << "Proper args required";
     }
-    app.m_query = QString::fromLatin1(argv[1]);
+    app.m_query = argv[1];
 
     return app.exec();
 }
 
 App::App(int& argc, char** argv, int flags)
-    : QApplication(argc, argv, flags)
+    : QCoreApplication(argc, argv, flags)
 {
     QTimer::singleShot(0, this, SLOT(main()));
 }
@@ -62,7 +62,7 @@ using namespace Baloo;
 void App::main()
 {
     Query q;
-    q.addType(QLatin1String("File"));
+    q.addType("File");
     q.setSearchString(m_query);
     q.setLimit(10);
 
@@ -74,5 +74,4 @@ void App::main()
     quit();
 }
 
-
 #include "querytest.moc"
