@@ -373,21 +373,4 @@ void KInotifyTest::testMoveRootFolder()
     QVERIFY(kn.watchingPath(dest));
 }
 
-void KInotifyTest::testFileClosedAfterWrite()
-{
-    QTemporaryDir dir;
-    touchFile(dir.path() + QLatin1String("/file"));
-
-    KInotify kn;
-    kn.addWatch(dir.path(), KInotify::EventAll);
-
-    QSignalSpy spy(&kn, SIGNAL(closedWrite(QString)));
-    touchFile(dir.path() + QLatin1String("/file"));
-
-    waitForSignal(&kn, SIGNAL(closedWrite(QString)));
-    QCOMPARE(spy.count(), 1);
-    QCOMPARE(spy.at(0).first().toString(), QString(dir.path() + QLatin1String("/file")));
-}
-
-
 QTEST_MAIN(KInotifyTest)
