@@ -29,16 +29,15 @@
 #include <QDateTime>
 #include <QStringList>
 
-#include <KFileMetaData/TypeInfo>
+#include <kfilemetadata/typeinfo.h>
 #include <QDebug>
 
 using namespace Baloo;
 
-BasicIndexingJob::BasicIndexingJob(const FileMapping& file, const QString& mimetype,
-                                   bool onlyBasicIndexing)
-    : m_file(file)
+BasicIndexingJob::BasicIndexingJob(QSqlDatabase* db, const FileMapping& file, const QString& mimetype)
+    : m_sqlDb(db)
+    , m_file(file)
     , m_mimetype(mimetype)
-    , m_onlyBasicIndexing(onlyBasicIndexing)
     , m_id(0)
 {
 }
@@ -49,21 +48,28 @@ BasicIndexingJob::~BasicIndexingJob()
 
 bool BasicIndexingJob::index()
 {
+    if (m_file.id() == 0) {
+        if (!m_file.create(*m_sqlDb)) {
+            qWarning() << "Cannot create fileMapping for" << m_file.url();
+            return false;
+        }
+    }
+
     QFileInfo fileInfo(m_file.url());
 
     XapianDocument doc;
-    doc.addBoolTerm(m_mimetype, QLatin1String("M"));
+    doc.addTerm(m_mimetype, "M");
     doc.indexText(fileInfo.fileName(), 1000);
-    doc.indexText(fileInfo.fileName(), QLatin1String("F"), 1000);
+    doc.indexText(fileInfo.fileName(), "F", 1000);
 
     // Modified Date
     QDateTime mod = fileInfo.lastModified();
     const QString dtm = mod.toString(Qt::ISODate);
 
-    doc.addBoolTerm(dtm, QLatin1String("DT_M"));
-    doc.addBoolTerm(mod.date().year(), QLatin1String("DT_MY"));
-    doc.addBoolTerm(mod.date().month(), QLatin1String("DT_MM"));
-    doc.addBoolTerm(mod.date().day(), QLatin1String("DT_MD"));
+    doc.addBoolTerm(dtm, "DT_M");
+    doc.addBoolTerm(mod.date().year(), "DT_MY");
+    doc.addBoolTerm(mod.date().month(), "DT_MM");
+    doc.addBoolTerm(mod.date().day(), "DT_MD");
 
     const QString timeTStr = QString::number(mod.toTime_t());
     doc.addValue(0, timeTStr);
@@ -73,62 +79,49 @@ bool BasicIndexingJob::index()
     QVector<KFileMetaData::Type::Type> tList = typesForMimeType(m_mimetype);
     Q_FOREACH (KFileMetaData::Type::Type type, tList) {
         QString tstr = KFileMetaData::TypeInfo(type).name().toLower();
-        doc.addBoolTerm(tstr, QLatin1String("T"));
+        doc.addBoolTerm(tstr, "T");
     }
 
     if (fileInfo.isDir()) {
-        doc.addBoolTerm(QLatin1String("folder"), QLatin1String("T"));
+        doc.addBoolTerm("folder", "T");
 
         // This is an optimization for folders. They do not need to go through
         // file indexing, so there are no indexers for folders
-        doc.addBoolTerm(QLatin1String("Z2"));
-    }
-    else if (m_onlyBasicIndexing) {
-        // This is to prevent indexing if option in config is set to do so
-        doc.addBoolTerm(QLatin1String("Z2"));
+        doc.addBoolTerm("Z2");
     }
     else {
-        doc.addBoolTerm(QLatin1String("Z1"));
+        doc.addBoolTerm("Z1");
     }
 
-    indexXAttr(m_file.url(), doc);
-
-    m_id = m_file.id();
-    m_doc = doc.doc();
-    return true;
-}
-
-bool BasicIndexingJob::indexXAttr(const QString& url, XapianDocument& doc)
-{
-    bool modified = false;
+    //
+    // X-Attr terms
+    //
     QString val;
 
-    baloo_getxattr(url, QLatin1String("user.xdg.tags"), &val);
+    baloo_getxattr(m_file.url(), QLatin1String("user.xdg.tags"), &val);
     if (!val.isEmpty()) {
-        const QStringList tags = val.split(QLatin1Char(','), QString::SkipEmptyParts);
+        QStringList tags = val.split(QLatin1Char(','), QString::SkipEmptyParts);
         Q_FOREACH (const QString& tag, tags) {
             doc.indexText(tag, QLatin1String("TA"));
             doc.addBoolTerm(QLatin1String("TAG-") + tag);
         }
-
-        modified = true;
     }
 
     val.clear();
-    baloo_getxattr(url, QLatin1String("user.baloo.rating"), &val);
+    baloo_getxattr(m_file.url(), QLatin1String("user.baloo.rating"), &val);
     if (!val.isEmpty()) {
         doc.addBoolTerm(val, QLatin1String("R"));
-        modified = true;
     }
 
     val.clear();
-    baloo_getxattr(url, QLatin1String("user.xdg.comment"), &val);
+    baloo_getxattr(m_file.url(), QLatin1String("user.xdg.comment"), &val);
     if (!val.isEmpty()) {
         doc.indexText(val, QLatin1String("C"));
-        modified = true;
     }
 
-    return modified;
+    m_id = m_file.id();
+    m_doc = doc.doc();
+    return true;
 }
 
 QVector<KFileMetaData::Type::Type> BasicIndexingJob::typesForMimeType(const QString& mimeType) const
