@@ -58,12 +58,7 @@ enum UpdateDirFlag {
      * The files in the folder should be updated regardless
      * of their state.
      */
-    ForceUpdate = 0x4,
-
-    /**
-     * Only update the extended attributes of the file
-     */
-    ExtendedAttributesOnly = 0x8
+    ForceUpdate = 0x4
 };
 Q_DECLARE_FLAGS(UpdateDirFlags, UpdateDirFlag)
 
@@ -98,7 +93,7 @@ private:
      * This method does not need to be synchronous. The indexing operation may be started
      * and on completion, the finishedIndexing method should be called
      */
-    void index(FileMapping& file, const QString& mimetype, UpdateDirFlags flags);
+    void index(const FileMapping& file, const QString& mimetype);
 
     bool shouldIndex(FileMapping& file, const QString& mimetype) const;
     bool shouldIndexContents(const QString& dir);
