@@ -35,8 +35,7 @@
 #include <QSqlError>
 #include <QDBusConnection>
 
-#include <KFileMetaData/Extractor>
-#include <KFileMetaData/PropertyInfo>
+#include <kfilemetadata/propertyinfo.h>
 
 #include <iostream>
 
@@ -52,7 +51,6 @@ App::App(const QString& path, QObject* parent)
         QTimer::singleShot(0, QCoreApplication::instance(), SLOT(quit()));
         return;
     }
-    m_db.sqlDatabase().transaction();
 
     connect(this, SIGNAL(saved()), this, SLOT(processNextUrl()), Qt::QueuedConnection);
 }
@@ -96,7 +94,7 @@ void App::startProcessing(const QStringList& args)
 void App::processNextUrl()
 {
     if (m_urls.isEmpty()) {
-        if (m_results.isEmpty() && m_docsToDelete.isEmpty()) {
+        if (m_results.isEmpty()) {
             QCoreApplication::instance()->exit(0);
         }
         else {
@@ -108,7 +106,7 @@ void App::processNextUrl()
     const QString url = m_urls.takeFirst();
     QString mimetype = m_mimeDb.mimeTypeForFile(url).name();
 
-    if (!ignoreConfig()) {
+    if (!m_ignoreConfig) {
         bool shouldIndex = m_config.shouldBeIndexed(url) && m_config.shouldMimeTypeBeIndexed(mimetype);
         if (!shouldIndex) {
             qDebug() << url << "should not be indexed. Ignoring";
@@ -128,8 +126,7 @@ void App::processNextUrl()
     // have trouble processing them
     //
     if (mimetype == QLatin1String("text/plain")) {
-        if (!url.endsWith(QLatin1String(".txt"))) {
-            qDebug() << "text/plain does not end with .txt. Ignoring";
+        if (!url.endsWith(".txt")) {
             mimetype.clear();
         }
 
@@ -140,39 +137,67 @@ void App::processNextUrl()
     }
 
     FileMapping file(url);
-    if (!file.fetch(m_db.sqlDatabase())) {
-        file.create(m_db.sqlDatabase());
+    if (!m_bData) {
+        if (!file.fetch(m_db.sqlDatabase())) {
+            file.create(m_db.sqlDatabase());
+        }
     }
 
     // We always run the basic indexing again. This is mostly so that the proper
     // mimetype is set and we get proper type information.
     // The mimetype fetched in the BasicIQ is fast but not accurate
-    BasicIndexingJob basicIndexer(file, mimetype, true /*Indexing Level 2*/);
+    BasicIndexingJob basicIndexer(&m_db.sqlDatabase(), file, mimetype);
     basicIndexer.index();
 
     file.setId(basicIndexer.id());
     Xapian::Document doc = basicIndexer.document();
 
-    Result result(url, mimetype, KFileMetaData::ExtractionResult::ExtractEverything);
+    Result result(url, mimetype);
     result.setId(file.id());
     result.setDocument(doc);
+    result.setReadOnly(m_bData);
 
-    QList<KFileMetaData::Extractor*> exList = m_extractorCollection.fetchExtractors(mimetype);
+    QList<KFileMetaData::ExtractorPlugin*> exList = m_manager.fetchExtractors(mimetype);
 
-    Q_FOREACH (KFileMetaData::Extractor* ex, exList) {
-        ex->extract(&result);
+    Q_FOREACH (KFileMetaData::ExtractorPlugin* plugin, exList) {
+        plugin->extract(&result);
     }
     m_results << result;
     m_termCount += result.document().termlist_count();
 
     // Documents with these many terms occupy about 10 mb
-    if (m_termCount >= 10000) {
+    if (m_termCount >= 10000 && !m_bData) {
         saveChanges();
         return;
     }
 
     if (m_urls.isEmpty()) {
-        saveChanges();
+        if (m_bData) {
+            QByteArray arr;
+            QDataStream s(&arr, QIODevice::WriteOnly);
+
+            Q_FOREACH (const Result& res, m_results) {
+                QVariantMap map;
+
+                QMapIterator<QString, QVariant> it(res.map());
+                while (it.hasNext()) {
+                    it.next();
+                    int propNum = it.key().toInt();
+
+                    using namespace KFileMetaData::Property;
+                    Property prop = static_cast<Property>(propNum);
+                    KFileMetaData::PropertyInfo pi(prop);
+                    map.insert(pi.name(), it.value());
+                }
+                s << map;
+            }
+
+            std::cout << arr.toBase64().constData();
+            m_results.clear();
+        }
+        else {
+            saveChanges();
+        }
     }
 
     QTimer::singleShot(0, this, SLOT(processNextUrl()));
@@ -180,13 +205,13 @@ void App::processNextUrl()
 
 void App::saveChanges()
 {
-    if (m_results.isEmpty() && m_docsToDelete.isEmpty())
+    if (m_results.isEmpty())
         return;
 
     m_updatedFiles.clear();
 
     XapianDatabase xapDb(m_path);
-    for (int i = 0; i<m_results.size(); ++i) {
+    for (int i = 0; i<m_results.size(); i++) {
         Result& res = m_results[i];
         res.finish();
 
@@ -197,11 +222,14 @@ void App::saveChanges()
     Q_FOREACH (int docid, m_docsToDelete) {
         xapDb.deleteDocument(docid);
     }
-    m_docsToDelete.clear();
 
     xapDb.commit();
     m_db.sqlDatabase().commit();
 
+    m_results.clear();
+    m_termCount = 0;
+    m_updatedFiles.clear();
+
     QDBusMessage message = QDBusMessage::createSignal(QLatin1String("/files"),
                                                       QLatin1String("org.kde"),
                                                       QLatin1String("changed"));
@@ -213,10 +241,6 @@ void App::saveChanges()
 
     QDBusConnection::sessionBus().send(message);
 
-    m_results.clear();
-    m_termCount = 0;
-    m_updatedFiles.clear();
-
     if (m_debugEnabled) {
         printDebug();
     }
@@ -241,7 +265,7 @@ void App::printDebug()
     }
 
     // Print the io usage
-    QFile file(QLatin1String("/proc/self/io"));
+    QFile file("/proc/self/io");
     file.open(QIODevice::ReadOnly | QIODevice::Text);
 
     QTextStream fs(&file);
@@ -252,25 +276,25 @@ void App::printDebug()
     while (!stream.atEnd()) {
         QString str = stream.readLine();
 
-        QString rchar(QLatin1String("rchar: "));
+        QString rchar("rchar: ");
         if (str.startsWith(rchar)) {
             ulong amt = str.mid(rchar.size()).toULong();
             qDebug() << "Read:" << amt / 1024  << "kb";
         }
 
-        QString wchar(QLatin1String("wchar: "));
+        QString wchar("wchar: ");
         if (str.startsWith(wchar)) {
             ulong amt = str.mid(wchar.size()).toULong();
             qDebug() << "Write:" << amt / 1024  << "kb";
         }
 
-        QString read(QLatin1String("read_bytes: "));
+        QString read("read_bytes: ");
         if (str.startsWith(read)) {
             ulong amt = str.mid(read.size()).toULong();
             qDebug() << "Actual Reads:" << amt / 1024  << "kb";
         }
 
-        QString write(QLatin1String("write_bytes: "));
+        QString write("write_bytes: ");
         if (str.startsWith(write)) {
             ulong amt = str.mid(write.size()).toULong();
             qDebug() << "Actual Writes:" << amt / 1024  << "kb";
@@ -278,8 +302,3 @@ void App::printDebug()
     }
 
 }
-
-bool App::ignoreConfig() const
-{
-    return m_ignoreConfig;
-}
