@@ -27,7 +27,8 @@
 #include <QStringList>
 #include <QMimeDatabase>
 
-#include <KFileMetaData/ExtractorCollection>
+#include <kfilemetadata/extractorpluginmanager.h>
+#include <kfilemetadata/extractorplugin.h>
 
 #include "result.h"
 #include "../database.h"
@@ -43,6 +44,7 @@ public:
     explicit App(const QString& path, QObject* parent = 0);
 
     void setDebug(bool status) { m_debugEnabled = status; }
+    void setBData(bool status) { m_bData = status; }
     void setIgnoreConfig(bool status) { m_ignoreConfig = status; }
 
     void startProcessing(const QStringList& args);
@@ -56,10 +58,10 @@ Q_SIGNALS:
 
 private:
     void printDebug();
-    bool ignoreConfig() const;
 
     QVector<Result> m_results;
     QStringList m_urls;
+    bool m_bData;
     bool m_debugEnabled;
     bool m_ignoreConfig;
 
@@ -68,7 +70,7 @@ private:
     Database m_db;
     QMimeDatabase m_mimeDb;
 
-    KFileMetaData::ExtractorCollection m_extractorCollection;
+    KFileMetaData::ExtractorPluginManager m_manager;
 
     int m_termCount;
     QList<QString> m_updatedFiles;
