@@ -35,7 +35,7 @@ using namespace KAuth;
  */
 bool raiselimitPermanently(int newLimit)
 {
-    QFile sysctl(QLatin1String("/etc/sysctl.d/97-kde-baloo-filewatch-inotify.conf"));
+    QFile sysctl("/etc/sysctl.d/97-kde-baloo-filewatch-inotify.conf");
     //Just overwrite the existing file.
     if (sysctl.open(QIODevice::WriteOnly)) {
         QTextStream sysc(&sysctl);
@@ -51,26 +51,26 @@ ActionReply FileWatchHelper::raiselimit(QVariantMap args)
     Q_UNUSED(args);
 
     // Open the procfs file that controls the number of inotify user watches
-    QFile inotctl(QLatin1String("/proc/sys/fs/inotify/max_user_watches"));
+    QFile inotctl("/proc/sys/fs/inotify/max_user_watches");
     if (!inotctl.open(QIODevice::ReadWrite))
-        return ActionReply::HelperErrorReply;
+        return ActionReply::HelperErrorReply();
     QTextStream inot(&inotctl);
     // Read the current number
     QString curr = inot.readLine();
     bool ok;
     int now = curr.toInt(&ok);
     if (!ok)
-        return ActionReply::HelperErrorReply;
+        return ActionReply::HelperErrorReply();
     // Write the new number, which is double the current number
     int next = now*2;
     // Check for overflow
     if (next < now)
-        return ActionReply::HelperErrorReply;
+        return ActionReply::HelperErrorReply();
 
     inot << next << "\n";
     inotctl.close();
     raiselimitPermanently(next);
-    return ActionReply::SuccessReply;
+    return ActionReply::SuccessReply();
 }
 
-KDE4_AUTH_HELPER_MAIN("org.kde.baloo.filewatch", FileWatchHelper)
+KAUTH_HELPER_MAIN("org.kde.baloo.filewatch", FileWatchHelper)
