@@ -26,7 +26,7 @@
 #include "file.h"
 #include "file_p.h"
 #include "searchstore.h"
-#include "baloo_xattr_p.h"
+#include "filecustommetadata.h"
 
 #include <QTimer>
 #include <QFile>
@@ -90,14 +90,14 @@ void FileFetchJob::doStart()
         const QString& url = file.url();
         if (url.size() && !QFile::exists(url)) {
             setError(Error_FileDoesNotExist);
-            setErrorText(QLatin1String("File ") + url + QLatin1String(" does not exist"));
+            setErrorText("File " + url + " does not exist");
             emitResult();
             return;
         }
 
         if (file.id().size() && !file.id().startsWith("file")) {
             setError(Error_InvalidId);
-            setErrorText(QLatin1String("Invalid Id ") + QString::fromUtf8(file.id()));
+            setErrorText("Invalid Id " + QString::fromUtf8(file.id()));
             emitResult();
             return;
         }
@@ -152,18 +152,12 @@ void FileFetchJob::doStart()
 void FileFetchJob::Private::fetchUserMetadata(File& file)
 {
     const QString url = file.url();
-
-    QString rating;
-    baloo_getxattr(url, QLatin1String("user.baloo.rating"), &rating);
-
-    QString tags;
-    baloo_getxattr(url, QLatin1String("user.xdg.tags"), &tags);
-
-    QString comment;
-    baloo_getxattr(url, QLatin1String("user.xdg.comment"), &comment);
+    QString rating = customFileMetaData(url, QLatin1String("user.baloo.rating"));
+    QString tags = customFileMetaData(url, QLatin1String("user.xdg.tags"));
+    QString comment = customFileMetaData(url, QLatin1String("user.xdg.comment"));
 
     file.setRating(rating.toInt());
-    file.setTags(tags.split(QLatin1Char(','), QString::SkipEmptyParts));
+    file.setTags(tags.split(',', QString::SkipEmptyParts));
     file.setUserComment(comment);
 }
 
