@@ -27,7 +27,6 @@
 #include <KConfig>
 #include <KConfigGroup>
 #include <QDebug>
-#include <QFileInfo>
 #include <iostream>
 
 #include "filewatch.h"
@@ -38,7 +37,6 @@
 
 #include <QDBusConnection>
 #include <QApplication>
-#include <QSessionManager>
 
 int main(int argc, char** argv)
 {
@@ -46,24 +44,19 @@ int main(int argc, char** argv)
     lowerSchedulingPriority();
     lowerPriority();
 
-    KAboutData aboutData(QLatin1String("baloo_file"), i18n("Baloo File"), PROJECT_VERSION,
+    KAboutData aboutData("baloo_file", i18n("Baloo File"), "0.1",
                          i18n("An application to handle file metadata"),
                          KAboutLicense::LGPL_V2);
-    aboutData.addAuthor(i18n("Vishesh Handa"), i18n("Maintainer"), QLatin1String("me@vhanda.in"), QLatin1String("http://vhanda.in"));
+    aboutData.addAuthor(i18n("Vishesh Handa"), i18n("Maintainer"), "me@vhanda.in", "http://vhanda.in");
 
     KAboutData::setApplicationData(aboutData);
 
-    QApplication::setDesktopSettingsAware(false);
     QApplication app(argc, argv);
     app.setQuitOnLastWindowClosed(false);
+    //KUniqueApplication app(true);
+    //app.disableSessionManagement();
 
-    auto disableSessionManagement = [](QSessionManager &sm) {
-        sm.setRestartHint(QSessionManager::RestartNever);
-    };
-    QObject::connect(&app, &QGuiApplication::commitDataRequest, disableSessionManagement);
-    QObject::connect(&app, &QGuiApplication::saveStateRequest, disableSessionManagement);
-
-    KConfig config(QLatin1String("baloofilerc"));
+    KConfig config("baloofilerc");
     KConfigGroup group = config.group("Basic Settings");
     bool indexingEnabled = group.readEntry("Indexing-Enabled", true);
 
@@ -73,7 +66,7 @@ int main(int argc, char** argv)
     }
 
 
-    if (!QDBusConnection::sessionBus().registerService(QLatin1String("org.kde.baloo.file"))) {
+    if (!QDBusConnection::sessionBus().registerService("org.kde.baloo.file")) {
         qWarning() << "Failed to register via dbus. Another instance is running";
         return 1;
     }
@@ -81,7 +74,7 @@ int main(int argc, char** argv)
     // Crash Handling
     KCrash::setFlags(KCrash::AutoRestart);
 
-    const QString path = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/baloo/file/");
+    const QString path = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + "/baloo/file/";
 
     Database db;
     db.setPath(path);
@@ -95,8 +88,6 @@ int main(int argc, char** argv)
 
     QObject::connect(&filewatcher, SIGNAL(indexFile(QString)),
                      &fileIndexer, SLOT(indexFile(QString)));
-    QObject::connect(&filewatcher, SIGNAL(indexXAttr(QString)),
-                     &fileIndexer, SLOT(indexXAttr(QString)));
     QObject::connect(&filewatcher, SIGNAL(installedWatches()),
                      &fileIndexer, SLOT(update()));
     QObject::connect(&filewatcher, SIGNAL(fileRemoved(int)),
