@@ -1,7 +1,6 @@
 /*
-   This file is part of the KDE Baloo project.
+   This file is part of the Nepomuk KDE project.
    Copyright (C) 2010 Sebastian Trueg <trueg@kde.org>
-   Copyright (C) 2014 Vishesh Handa <me@vhanda.in>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -36,23 +35,31 @@ RegExpCache::~RegExpCache()
 
 bool RegExpCache::exactMatch(const QString& s) const
 {
-    Q_FOREACH(const QRegularExpression& filter, m_regexpCache) {
-        if (filter.match(s).hasMatch()) {
+    Q_FOREACH(const QRegExp & filter, m_regexpCache) {
+        if (filter.exactMatch(s)) {
             return true;
         }
     }
     return false;
 }
 
+
+bool RegExpCache::filenameMatch(const QString& path) const
+{
+    QString name;
+    int i = path.lastIndexOf('/');
+    if (i >= 0)
+        name = path.mid(i + 1);
+    else
+        name = path;
+    return exactMatch(name);
+}
+
+
 void RegExpCache::rebuildCacheFromFilterList(const QStringList& filters)
 {
     m_regexpCache.clear();
-    Q_FOREACH (const QString& filter, filters) {
-        QString f = filter;
-        f.replace(QLatin1Char('?'), QLatin1Char('.'));
-        f.replace(QStringLiteral("*"), QStringLiteral(".*"));
-        f = QLatin1String("^") + f + QLatin1String("$");
-
-        m_regexpCache.append(QRegularExpression(f));
+    Q_FOREACH(const QString & filter, filters) {
+        m_regexpCache.append(QRegExp(filter, Qt::CaseSensitive, QRegExp::Wildcard));
     }
 }
