@@ -22,7 +22,7 @@
 
 #include "pathfilterpostingsource.h"
 #include "filemapping.h"
-#include <KDebug>
+#include <QDebug>
 #include <QSqlQuery>
 #include <QSqlError>
 
@@ -33,8 +33,8 @@ PathFilterPostingSource::PathFilterPostingSource(QSqlDatabase* sqlDb, const QStr
     , m_includeDir(includeDir)
     , m_first(false)
 {
-    if (!m_includeDir.endsWith(QLatin1Char('/')))
-        m_includeDir.append(QLatin1Char('/'));
+    if (!m_includeDir.endsWith('/'))
+        m_includeDir.append('/');
 }
 
 PathFilterPostingSource::~PathFilterPostingSource()
@@ -108,7 +108,7 @@ void PathFilterPostingSource::skip_to(Xapian::docid did, Xapian::weight)
 
     if (!query.exec(str)) {
         m_iter = m_end;
-        kDebug() << query.lastError().text();
+        qDebug() << query.lastError().text();
         return;
     }
 
