@@ -25,7 +25,7 @@
 #include <QTime>
 #include <QCoreApplication>
 
-#include "fileextractor.h"
+#include "fileindexer.h"
 
 #include "../basicindexingqueue.h"
 #include "../commitqueue.h"
@@ -68,12 +68,12 @@ int main(int argc, char** argv)
     QHash<QString, int> m_numPerType;
 
     uint totalTime = 0;
-    for (; it != mset.end(); ++it) {
+    for (; it != mset.end(); it++) {
         Baloo::FileMapping fileMap(*it);
         if (!fileMap.fetch(db.sqlDatabase()))
             continue;
 
-        auto job = new Baloo::FileExtractor(fileMap.id(), fileMap.url());
+        Baloo::FileIndexer* job = new Baloo::FileIndexer(fileMap.id(), fileMap.url());
         job->setCustomPath(db.path());
         job->exec();
 
