@@ -23,15 +23,23 @@
 #include "kio_tags.h"
 
 #include <QUrl>
-#include <QDebug>
-
-#include <KLocalizedString>
-#include <KUser>
+#include <kio/global.h>
+#include <klocale.h>
 #include <kio/job.h>
+#include <KUser>
+#include <QDebug>
+#include <KLocalizedString>
+#include <kio/netaccess.h>
+#include <KComponentData>
+#include <KUrl>
 
 #include <QCoreApplication>
 #include <QDateTime>
-#include <QDir>
+#include <QDBusConnection>
+#include <QDBusConnectionInterface>
+
+#include <sys/types.h>
+#include <unistd.h>
 
 #include "file.h"
 #include "filemodifyjob.h"
@@ -90,18 +98,18 @@ void TagsProtocol::listDir(const QUrl& url)
         job->exec();
 
         Q_FOREACH (const QString& tag, job->tags()) {
-            listEntry(createUDSEntryForTag(tag));
+            listEntry(createUDSEntryForTag(tag), false);
         }
 
+        listEntry(KIO::UDSEntry(), true);
         finished();
         return;
     }
 
     case TagUrl: {
         Query q;
-        q.addType(QLatin1String("File"));
-        q.setTerm(Term(QLatin1String("tag"), tag));
-        q.setSortingOption(Query::SortNone);
+        q.addType("File");
+        q.setTerm(Term("tag", tag));
 
         ResultIterator it = q.exec();
         while (it.next()) {
@@ -127,9 +135,10 @@ void TagsProtocol::listDir(const QUrl& url)
             uds.insert(KIO::UDSEntry::UDS_TARGET_URL, url.url());
             uds.insert(KIO::UDSEntry::UDS_LOCAL_PATH, fileUrl);
 
-            listEntry(uds);
+            listEntry(uds, false);
         }
 
+        listEntry(KIO::UDSEntry(), true);
         finished();
     }
 
@@ -182,7 +191,7 @@ void TagsProtocol::stat(const QUrl& url)
     }
 }
 
-void TagsProtocol::copy(const QUrl& src, const QUrl& dest, int, KIO::JobFlags)
+void TagsProtocol::copy(const QUrl& src, const QUrl& dest, int permissions, KIO::JobFlags flags)
 {
     qDebug() << src << dest;
 
@@ -278,12 +287,10 @@ void TagsProtocol::rename(const QUrl& src, const QUrl& dest, KIO::JobFlags flags
         // Yes, this is weird, but it is required
         // It is required cause the dest url is of the form tags:/tag/file_url_with_new_filename
         // So we extract the new fileUrl from the 'src', and apply the new file to the dest
-        QString destUrl = fileUrl;
-        int lastIndex = destUrl.lastIndexOf(QDir::separator());
-        destUrl.resize(lastIndex + 1);
-        destUrl.append(dest.fileName());
+        KUrl destUrl(fileUrl);
+        destUrl.setFileName(dest.fileName());
 
-        ForwardingSlaveBase::rename(fileUrl, QUrl(destUrl), flags);
+        ForwardingSlaveBase::rename(fileUrl, destUrl, flags);
         return;
     }
     }
@@ -291,7 +298,6 @@ void TagsProtocol::rename(const QUrl& src, const QUrl& dest, KIO::JobFlags flags
 
 void TagsProtocol::del(const QUrl& url, bool isfile)
 {
-    Q_UNUSED(url)
     Q_UNUSED(isfile);
     /*
 
@@ -348,7 +354,7 @@ void TagsProtocol::mimetype(const QUrl& url)
 
     case RootUrl:
     case TagUrl:
-        mimeType(QLatin1String("inode/directory"));
+        mimeType("inode/directory");
         finished();
         return;
 
@@ -380,7 +386,7 @@ QString TagsProtocol::encodeFileUrl(const QString& url)
 }
 
 
-TagsProtocol::ParseResult TagsProtocol::parseUrl(const QUrl& url, QString& tag, QString& fileUrl, bool)
+TagsProtocol::ParseResult TagsProtocol::parseUrl(const QUrl& url, QString& tag, QString& fileUrl, bool ignoreErrors)
 {
     QString path = url.path();
     if (path.isEmpty() || path == QLatin1String("/"))
@@ -409,10 +415,9 @@ TagsProtocol::ParseResult TagsProtocol::parseUrl(const QUrl& url, QString& tag,
 
 extern "C"
 {
-    Q_DECL_EXPORT int kdemain(int argc, char** argv)
+    Q_DECL_EXPORT int kdemain(int, char** argv)
     {
-        QCoreApplication app(argc, argv);
-        app.setApplicationName(QStringLiteral("kio_tags"));
+        KComponentData("kio_tags");
         Baloo::TagsProtocol slave(argv[2], argv[3]);
         slave.dispatchLoop();
         return 0;
