@@ -90,100 +90,100 @@ Baloo::Term recursiveEmailTermMapping(const Akonadi::SearchTerm &term)
             case Akonadi::EmailSearchTerm::Message: {
                 Baloo::Term s(Baloo::Term::Or);
                 s.setNegation(term.isNegated());
-                s.addSubTerm(Baloo::Term(QLatin1String("body"), term.value(), mapComparator(term.condition())));
-                s.addSubTerm(Baloo::Term(QLatin1String("headers"), term.value(), mapComparator(term.condition())));
+                s.addSubTerm(Baloo::Term("body", term.value(), mapComparator(term.condition())));
+                s.addSubTerm(Baloo::Term("headers", term.value(), mapComparator(term.condition())));
                 return s;
             }
             case Akonadi::EmailSearchTerm::Body:
-                return getTerm(term, QLatin1String("body"));
+                return getTerm(term, "body");
             case Akonadi::EmailSearchTerm::Headers:
-                return getTerm(term, QLatin1String("headers"));
+                return getTerm(term, "headers");
             case Akonadi::EmailSearchTerm::ByteSize:
-                return getTerm(term, QLatin1String("size"));
+                return getTerm(term, "size");
             case Akonadi::EmailSearchTerm::HeaderDate: {
-                Baloo::Term s(QLatin1String("date"), QString::number(term.value().toDateTime().toTime_t()), mapComparator(term.condition()));
+                Baloo::Term s("date", QString::number(term.value().toDateTime().toTime_t()), mapComparator(term.condition()));
                 s.setNegation(term.isNegated());
                 return s;
             }
             case Akonadi::EmailSearchTerm::HeaderOnlyDate: {
-                Baloo::Term s(QLatin1String("onlydate"), QString::number(term.value().toDate().toJulianDay()), mapComparator(term.condition()));
+                Baloo::Term s("onlydate", QString::number(term.value().toDate().toJulianDay()), mapComparator(term.condition()));
                 s.setNegation(term.isNegated());
                 return s;
             }
             case Akonadi::EmailSearchTerm::Subject:
-                return getTerm(term, QLatin1String("subject"));
+                return getTerm(term, "subject");
             case Akonadi::EmailSearchTerm::HeaderFrom:
-                return getTerm(term, QLatin1String("from"));
+                return getTerm(term, "from");
             case Akonadi::EmailSearchTerm::HeaderTo:
-                return getTerm(term, QLatin1String("to"));
+                return getTerm(term, "to");
             case Akonadi::EmailSearchTerm::HeaderCC:
-                return getTerm(term, QLatin1String("cc"));
+                return getTerm(term, "cc");
             case Akonadi::EmailSearchTerm::HeaderBCC:
-                return getTerm(term, QLatin1String("bcc"));
+                return getTerm(term, "bcc");
             case Akonadi::EmailSearchTerm::MessageStatus:
                 if (term.value().toString() == QString::fromLatin1(Akonadi::MessageFlags::Flagged)) {
-                    return Baloo::Term(QLatin1String("isimportant"), !term.isNegated());
+                    return Baloo::Term("isimportant", !term.isNegated());
                 }
                 if (term.value().toString() == QString::fromLatin1(Akonadi::MessageFlags::ToAct)) {
-                    return Baloo::Term(QLatin1String("istoact"), !term.isNegated());
+                    return Baloo::Term("istoact", !term.isNegated());
                 }
                 if (term.value().toString() == QString::fromLatin1(Akonadi::MessageFlags::Watched)) {
-                    return Baloo::Term(QLatin1String("iswatched"), !term.isNegated());
+                    return Baloo::Term("iswatched", !term.isNegated());
                 }
                 if (term.value().toString() == QString::fromLatin1(Akonadi::MessageFlags::Deleted)) {
-                    return Baloo::Term(QLatin1String("isdeleted"), !term.isNegated());
+                    return Baloo::Term("isdeleted", !term.isNegated());
                 }
                 if (term.value().toString() == QString::fromLatin1(Akonadi::MessageFlags::Spam)) {
-                    return Baloo::Term(QLatin1String("isspam"), !term.isNegated());
+                    return Baloo::Term("isspam", !term.isNegated());
                 }
                 if (term.value().toString() == QString::fromLatin1(Akonadi::MessageFlags::Replied)) {
-                    return Baloo::Term(QLatin1String("isreplied"), !term.isNegated());
+                    return Baloo::Term("isreplied", !term.isNegated());
                 }
                 if (term.value().toString() == QString::fromLatin1(Akonadi::MessageFlags::Ignored)) {
-                    return Baloo::Term(QLatin1String("isignored"), !term.isNegated());
+                    return Baloo::Term("isignored", !term.isNegated());
                 }
                 if (term.value().toString() == QString::fromLatin1(Akonadi::MessageFlags::Forwarded)) {
-                    return Baloo::Term(QLatin1String("isforwarded"), !term.isNegated());
+                    return Baloo::Term("isforwarded", !term.isNegated());
                 }
                 if (term.value().toString() == QString::fromLatin1(Akonadi::MessageFlags::Sent)) {
-                    return Baloo::Term(QLatin1String("issent"), !term.isNegated());
+                    return Baloo::Term("issent", !term.isNegated());
                 }
                 if (term.value().toString() == QString::fromLatin1(Akonadi::MessageFlags::Queued)) {
-                    return Baloo::Term(QLatin1String("isqueued"), !term.isNegated());
+                    return Baloo::Term("isqueued", !term.isNegated());
                 }
                 if (term.value().toString() == QString::fromLatin1(Akonadi::MessageFlags::Ham)) {
-                    return Baloo::Term(QLatin1String("isham"), !term.isNegated());
+                    return Baloo::Term("isham", !term.isNegated());
                 }
                 if (term.value().toString() == QString::fromLatin1(Akonadi::MessageFlags::Seen)) {
-                    return Baloo::Term(QLatin1String("isread"), !term.isNegated());
+                    return Baloo::Term("isread", !term.isNegated());
                 }
                 if (term.value().toString() == QString::fromLatin1(Akonadi::MessageFlags::HasAttachment)) {
-                    return Baloo::Term(QLatin1String("hasattachment"), !term.isNegated());
+                    return Baloo::Term("hasattachment", !term.isNegated());
                 }
                 if (term.value().toString() == QString::fromLatin1(Akonadi::MessageFlags::Encrypted)) {
-                    return Baloo::Term(QLatin1String("isencrypted"), !term.isNegated());
+                    return Baloo::Term("isencrypted", !term.isNegated());
                 }
                 if (term.value().toString() == QString::fromLatin1(Akonadi::MessageFlags::HasInvitation)) {
-                    return Baloo::Term(QLatin1String("hasinvitation"), !term.isNegated());
+                    return Baloo::Term("hasinvitation", !term.isNegated());
                 }
                 break;
             case Akonadi::EmailSearchTerm::MessageTag:
                 //search directly in akonadi? or index tags.
                 break;
             case Akonadi::EmailSearchTerm::HeaderReplyTo:
-                return getTerm(term, QLatin1String("replyto"));
+                return getTerm(term, "replyto");
             case Akonadi::EmailSearchTerm::HeaderOrganization:
-                return getTerm(term, QLatin1String("organization"));
+                return getTerm(term, "organization");
             case Akonadi::EmailSearchTerm::HeaderListId:
-                return getTerm(term, QLatin1String("listid"));
+                return getTerm(term, "listid");
             case Akonadi::EmailSearchTerm::HeaderResentFrom:
-                return getTerm(term, QLatin1String("resentfrom"));
+                return getTerm(term, "resentfrom");
             case Akonadi::EmailSearchTerm::HeaderXLoop:
-                return getTerm(term, QLatin1String("xloop"));
+                return getTerm(term, "xloop");
             case Akonadi::EmailSearchTerm::HeaderXMailingList:
-                return getTerm(term, QLatin1String("xmailinglist"));
+                return getTerm(term, "xmailinglist");
             case Akonadi::EmailSearchTerm::HeaderXSpamFlag:
-                return getTerm(term, QLatin1String("xspamflag"));
+                return getTerm(term, "xspamflag");
             case Akonadi::EmailSearchTerm::Unknown:
             default:
                 qWarning() << "unknown term " << term.key();
@@ -194,29 +194,6 @@ Baloo::Term recursiveEmailTermMapping(const Akonadi::SearchTerm &term)
 
 Baloo::Term recursiveCalendarTermMapping(const Akonadi::SearchTerm &term)
 {
-    if (!term.subTerms().isEmpty()) {
-        Baloo::Term t(mapRelation(term.relation()));
-        Q_FOREACH (const Akonadi::SearchTerm &subterm, term.subTerms()) {
-            const Baloo::Term newTerm = recursiveCalendarTermMapping(subterm);
-            if (newTerm.isValid()) {
-                t.addSubTerm(newTerm);
-            }
-        }
-        return t;
-    } else {
-        qDebug() << term.key() << term.value();
-#if 0
-        const Akonadi::EmailSearchTerm::EmailSearchField field = Akonadi::EmailSearchTerm::fromKey(term.key());
-        switch (field) {
-        case Akonadi::EmailSearchTerm::Subject:
-            return getTerm(term, QLatin1String("subject");
-        case Akonadi::EmailSearchTerm::Body:
-            return getTerm(term, QLatin1String("body");
-        default:
-            kWarning() << "unknown term " << term.key();
-        }
-#endif
-    }
     return Baloo::Term();
 }
 
@@ -236,9 +213,9 @@ Baloo::Term recursiveNoteTermMapping(const Akonadi::SearchTerm &term)
         const Akonadi::EmailSearchTerm::EmailSearchField field = Akonadi::EmailSearchTerm::fromKey(term.key());
         switch (field) {
         case Akonadi::EmailSearchTerm::Subject:
-            return getTerm(term, QLatin1String("subject"));
+            return getTerm(term, "subject");
         case Akonadi::EmailSearchTerm::Body:
-            return getTerm(term, QLatin1String("body"));
+            return getTerm(term, "body");
         default:
             qWarning() << "unknown term " << term.key();
         }
@@ -262,13 +239,13 @@ Baloo::Term recursiveContactTermMapping(const Akonadi::SearchTerm &term)
         const Akonadi::ContactSearchTerm::ContactSearchField field = Akonadi::ContactSearchTerm::fromKey(term.key());
         switch (field) {
             case Akonadi::ContactSearchTerm::Name:
-                return getTerm(term, QLatin1String("name"));
+                return getTerm(term, "name");
             case Akonadi::ContactSearchTerm::Email:
-                return getTerm(term, QLatin1String("email"));
+                return getTerm(term, "email");
             case Akonadi::ContactSearchTerm::Nickname:
-                return getTerm(term, QLatin1String("nick"));
+                return getTerm(term, "nick");
             case Akonadi::ContactSearchTerm::Uid:
-                return getTerm(term, QLatin1String("uid"));
+                return getTerm(term, "uid");
             case Akonadi::ContactSearchTerm::Unknown:
             default:
                 qWarning() << "unknown term " << term.key();
@@ -294,21 +271,21 @@ QSet<qint64> SearchPlugin::search(const QString &akonadiQuery, const QList<qint6
 
     Baloo::Term t;
 
-    if (mimeTypes.contains(QLatin1String("message/rfc822"))) {
+    if (mimeTypes.contains("message/rfc822")) {
         qDebug() << "mail query";
-        query.setType(QLatin1String("Email"));
+        query.setType("Email");
         t = recursiveEmailTermMapping(term);
     } else if (mimeTypes.contains(KABC::Addressee::mimeType()) || mimeTypes.contains(KABC::ContactGroup::mimeType())) {
-        query.setType(QLatin1String("Contact"));
+        query.setType("Contact");
         t = recursiveContactTermMapping(term);
     } else if (mimeTypes.contains(QLatin1String("text/x-vnd.akonadi.note"))) {
-        query.setType(QLatin1String("Note"));
+        query.setType("Note");
         t = recursiveNoteTermMapping(term);
     } else if (mimeTypes.contains(QLatin1String("application/x-vnd.akonadi.calendar.event")) ||
                mimeTypes.contains(QLatin1String("application/x-vnd.akonadi.calendar.todo")) ||
                mimeTypes.contains(QLatin1String("application/x-vnd.akonadi.calendar.journal")) ||
                mimeTypes.contains(QLatin1String("application/x-vnd.akonadi.calendar.freebusy"))) {
-        query.setType(QLatin1String("Calendar"));
+        query.setType("Calendar");
         t = recursiveCalendarTermMapping(term);
     }
 
@@ -326,7 +303,7 @@ QSet<qint64> SearchPlugin::search(const QString &akonadiQuery, const QList<qint6
         Baloo::Term parentTerm(Baloo::Term::And);
         Baloo::Term collectionTerm(Baloo::Term::Or);
         Q_FOREACH (const qint64 col, collections) {
-            collectionTerm.addSubTerm(Baloo::Term(QLatin1String("collection"), QString::number(col)));
+            collectionTerm.addSubTerm(Baloo::Term("collection", QString::number(col)));
         }
         parentTerm.addSubTerm(collectionTerm);
         parentTerm.addSubTerm(t);
@@ -347,3 +324,6 @@ QSet<qint64> SearchPlugin::search(const QString &akonadiQuery, const QList<qint6
     qDebug() << "Got" << resultSet.count() << "results";
     return resultSet;
 }
+
+//QT5
+//Q_EXPORT_PLUGIN2(akonadi_baloo_searchplugin, SearchPlugin)
