@@ -54,7 +54,6 @@ class EmailQuery::Private
 
     EmailQuery::OpType opType;
     int limit;
-    bool splitSearchMatchString;
 };
 
 EmailQuery::Private::Private():
@@ -62,8 +61,7 @@ EmailQuery::Private::Private():
     read('0'),
     attachment('0'),
     opType(OpAnd),
-    limit(0),
-    splitSearchMatchString(true)
+    limit(0)
 {
 }
 
@@ -78,11 +76,6 @@ EmailQuery::~EmailQuery()
     delete d;
 }
 
-void EmailQuery::setSplitSearchMatchString(bool split)
-{
-    d->splitSearchMatchString = split;
-}
-
 void EmailQuery::setSearchType(EmailQuery::OpType op)
 {
     d->opType = op;
@@ -190,22 +183,13 @@ void EmailQuery::setRead(bool read)
 
 ResultIterator EmailQuery::exec()
 {
-    const QString dir = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/baloo/email/");
+    const QString dir = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + "/baloo/email/";
     Xapian::Database db;
     try {
         db = Xapian::Database(QFile::encodeName(dir).constData());
-    } catch (const Xapian::DatabaseOpeningError&) {
-        qWarning() << "Xapian Database does not exist at " << dir;
-        return ResultIterator();
-    } catch (const Xapian::DatabaseCorruptError&) {
-        qWarning() << "Xapian Database corrupted";
-        return ResultIterator();
     } catch (const Xapian::DatabaseError& e) {
         qWarning() << "Failed to open Xapian database:" << QString::fromStdString(e.get_error_string());
         return ResultIterator();
-    } catch (...) {
-        qWarning() << "Random exception, but we do not want to crash";
-        return ResultIterator();
     }
 
     QList<Xapian::Query> m_queries;
@@ -316,15 +300,10 @@ ResultIterator EmailQuery::exec()
         Xapian::QueryParser parser;
         parser.set_database(db);
         parser.set_default_op(Xapian::Query::OP_AND);
-        if (d->splitSearchMatchString) {
-            const QStringList list = d->matchString.split(QRegExp(QLatin1String("\\s")), QString::SkipEmptyParts);
-            Q_FOREACH (const QString& s, list) {
-                const QByteArray ba = s.toUtf8();
-                m_queries << parser.parse_query(ba.constData(),
-                                                Xapian::QueryParser::FLAG_PARTIAL);
-            }
-        } else {
-            const QByteArray ba = d->matchString.toUtf8();
+
+        const QStringList list = d->matchString.split(QRegExp("\\s"), QString::SkipEmptyParts);
+        Q_FOREACH (const QString& s, list) {
+            const QByteArray ba = s.toUtf8();
             m_queries << parser.parse_query(ba.constData(),
                                             Xapian::QueryParser::FLAG_PARTIAL);
         }
@@ -342,21 +321,15 @@ ResultIterator EmailQuery::exec()
     AgePostingSource ps(0);
     query = Xapian::Query(Xapian::Query::OP_AND_MAYBE, query, Xapian::Query(&ps));
 
-    try {
-        Xapian::Enquire enquire(db);
-        enquire.set_query(query);
+    Xapian::Enquire enquire(db);
+    enquire.set_query(query);
 
-        if (d->limit == 0)
-            d->limit = 1000000;
+    if (d->limit == 0)
+        d->limit = 1000000;
 
-        Xapian::MSet mset = enquire.get_mset(0, d->limit);
+    Xapian::MSet mset = enquire.get_mset(0, d->limit);
 
-        ResultIterator iter;
-        iter.d->init(mset);
-        return iter;
-    }
-    catch (const Xapian::Error &e) {
-        qWarning() << QString::fromStdString(e.get_type()) << QString::fromStdString(e.get_description());
-        return ResultIterator();
-    }
+    ResultIterator iter;
+    iter.d->init(mset);
+    return iter;
 }
