@@ -22,22 +22,19 @@
 
 #include "calendarsearchstore.h"
 
-#include <KStandardDirs>
-#include <KDebug>
-
 using namespace Baloo;
 
 CalendarSearchStore::CalendarSearchStore(QObject* parent)
     : PIMSearchStore(parent)
 {
-    m_prefix.insert(QLatin1String("collection"), QLatin1String("C"));
+    m_prefix.insert("collection", "C");
 
-    setDbPath(findDatabase(QLatin1String("calendars")));
+    setDbPath(findDatabase("calendars"));
 }
 
 QStringList CalendarSearchStore::types()
 {
-    return QStringList() << QLatin1String("Akonadi") << QLatin1String("Calendar");
+    return QStringList() << "Akonadi" << "Calendar";
 }
 
-BALOO_EXPORT_SEARCHSTORE(Baloo::CalendarSearchStore, "baloo_calendarsearchstore")
+#include "calendarsearchstore.moc"
