@@ -29,15 +29,16 @@ using namespace Baloo;
 NoteSearchStore::NoteSearchStore(QObject* parent)
     : PIMSearchStore(parent)
 {
-    m_prefix.insert(QLatin1String("subject"), QLatin1String("SU"));
-    m_prefix.insert(QLatin1String("collection"), QLatin1String("C"));
-    m_prefix.insert(QLatin1String("body"), QLatin1String("BO"));
+    m_prefix.insert("subject", "SU");
+    m_prefix.insert("collection", "C");
+    m_prefix.insert("body", "BO");
 
-    setDbPath(findDatabase(QLatin1String("notes")));
+    setDbPath(findDatabase("notes"));
 }
 
 QStringList NoteSearchStore::types()
 {
-    return QStringList() << QLatin1String("Akonadi") << QLatin1String("Note");
+    return QStringList() << "Akonadi" << "Note";
 }
 
+#include "notesearchstore.moc"
