@@ -21,7 +21,8 @@
 #ifndef _BALOO_SEARCH_RUNNER_H_
 #define _BALOO_SEARCH_RUNNER_H_
 
-#include <Plasma/AbstractRunner>
+#include <KRunner/AbstractRunner>
+#include <KRunner/QueryMatch>
 
 class SearchRunner : public Plasma::AbstractRunner
 {
@@ -37,6 +38,10 @@ public:
 
 protected Q_SLOTS:
     void init();
+
+private:
+    void match(Plasma::RunnerContext& context, const QString& type,
+               const QString& category);
 };
 
 #endif // _BALOO_SEARCH_RUNNER_H_
