@@ -1,6 +1,6 @@
 /*
  * This file is part of the KDE Baloo Project
- * Copyright (C) 2013-2014  Vishesh Handa <me@vhanda.in>
+ * Copyright (C) 2013  Vishesh Handa <me@vhanda.in>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -21,7 +21,6 @@
  */
 
 #include "xapiansearchstore.h"
-#include "xapianqueryparser.h"
 #include "term.h"
 #include "query.h"
 
@@ -36,8 +35,8 @@ using namespace Baloo;
 
 XapianSearchStore::XapianSearchStore(QObject* parent)
     : SearchStore(parent)
-    , m_mutex(QMutex::Recursive)
     , m_nextId(1)
+    , m_mutex(QMutex::Recursive)
     , m_db(0)
 {
 }
@@ -106,6 +105,9 @@ Xapian::Query XapianSearchStore::toXapianQuery(const Term& term)
         return negate(term.isNegated(), toXapianQuery(Xapian::Query::OP_OR, term.subTerms()));
     }
 
+    if (term.property().isEmpty())
+        return Xapian::Query();
+
     return negate(term.isNegated(), constructQuery(term.property(), term.value(), term.comparator()));
 }
 
@@ -121,12 +123,86 @@ Xapian::Query XapianSearchStore::andQuery(const Xapian::Query& a, const Xapian::
         return Xapian::Query(Xapian::Query::OP_AND, a, b);
 }
 
+namespace {
+    struct Term {
+        std::string t;
+        uint count;
+
+        // pop_heap pops the largest element, we want the smallest to be popped
+        bool operator < (const Term& rhs) const {
+            return count > rhs.count;
+        }
+    };
+
+    Xapian::Query makeQuery(const QString& string, Xapian::Database* db)
+    {
+        // Lets just keep the top x (+1 for push_heap)
+        static const int MaxTerms = 100;
+        QList<Term> topTerms;
+        topTerms.reserve(MaxTerms + 1);
+
+        const std::string stdString(string.toLower().toUtf8().constData());
+        Xapian::TermIterator it = db->allterms_begin(stdString);
+        Xapian::TermIterator end = db->allterms_end(stdString);
+        for (; it != end; it++) {
+            Term term;
+            term.t = *it;
+            term.count = db->get_collection_freq(term.t);
+
+            if (topTerms.size() < MaxTerms) {
+                topTerms.push_back(term);
+                std::push_heap(topTerms.begin(), topTerms.end());
+            }
+            else {
+                // Remove the term with the min count
+                topTerms.push_back(term);
+                std::push_heap(topTerms.begin(), topTerms.end());
+
+                std::pop_heap(topTerms.begin(), topTerms.end());
+                topTerms.pop_back();
+            }
+        }
+
+        QVector<std::string> termStrings;
+        termStrings.reserve(topTerms.size());
+
+        Q_FOREACH (const Term& term, topTerms) {
+            termStrings << term.t;
+        }
+
+        Xapian::Query finalQ(Xapian::Query::OP_SYNONYM, termStrings.begin(), termStrings.end());
+        return finalQ;
+    }
+}
+
 
 Xapian::Query XapianSearchStore::constructSearchQuery(const QString& str)
 {
-    XapianQueryParser parser;
-    parser.setDatabase(m_db);
-    return parser.parseQuery(str);
+    QVector<Xapian::Query> queries;
+    QRegExp splitRegex("[\\s.+*/\\-=]");
+    QStringList list = str.split(splitRegex, QString::SkipEmptyParts);
+
+    QMutableListIterator<QString> iter(list);
+    while (iter.hasNext()) {
+        const QString str = iter.next();
+        if (str.size() <= 3) {
+            queries << makeQuery(str, m_db);
+            iter.remove();
+        }
+    }
+
+    if (!list.isEmpty()) {
+        std::string stdStr(list.join(" ").toUtf8().constData());
+
+        Xapian::QueryParser parser;
+        parser.set_database(*m_db);
+        parser.set_default_op(Xapian::Query::OP_AND);
+
+        int flags = Xapian::QueryParser::FLAG_DEFAULT | Xapian::QueryParser::FLAG_PARTIAL;
+        queries << parser.parse_query(stdStr, flags);
+    }
+
+    return Xapian::Query(Xapian::Query::OP_AND, queries.begin(), queries.end());
 }
 
 int XapianSearchStore::exec(const Query& query)
@@ -145,12 +221,6 @@ int XapianSearchStore::exec(const Query& query)
             }
 
             Xapian::Query xapQ = toXapianQuery(query.term());
-            // The term was not properly converted. Lets abort. The properties
-            // must not exist
-            if (!query.term().empty() && xapQ.empty()) {
-                qDebug() << query.term() << "could not be processed. Aborting";
-                return 0;
-            }
             if (query.searchString().size()) {
                 QString str = query.searchString();
 
@@ -162,17 +232,9 @@ int XapianSearchStore::exec(const Query& query)
             xapQ = applyCustomOptions(xapQ, query.customOptions());
             xapQ = finalizeQuery(xapQ);
 
-            if (xapQ.empty()) {
-                // Return all the results
-                xapQ = Xapian::Query(std::string());
-            }
             Xapian::Enquire enquire(*m_db);
             enquire.set_query(xapQ);
 
-            if (query.sortingOption() == Query::SortNone) {
-                enquire.set_weighting_scheme(Xapian::BoolWeight());
-            }
-
             Result& res = m_queryMap[m_nextId++];
             res.mset = enquire.get_mset(query.offset(), query.limit());
             res.it = res.mset.begin();
@@ -240,7 +302,7 @@ bool XapianSearchStore::next(int queryId)
     else {
         res.lastId = *res.it;
         res.lastUrl.clear();
-        ++res.it;
+        res.it++;
     }
 
     return !atEnd;
